env_is_missing

Function env_is_missing 

fn env_is_missing(key: &str) -> bool
Returns true if the variable is not set at all. The envOr cheatcodes fall back to their default only then (or when the variable is set but empty, for the scalar typed overloads); a variable that is set to a value that cannot be parsed is an error.